"use strict";

exports.__esModule = true;
exports.getScrollingParent = exports.getEdgeOffset = exports.getPosition = exports.closest = exports.setTransitionDuration = exports.setTranslate3d = exports.setInlineStyles = void 0;

var setInlineStyles = function setInlineStyles(node, styles) {
  return Object.keys(styles).forEach(function (key) {
    return node.style[key] = styles[key];
  });
};

exports.setInlineStyles = setInlineStyles;

var setTranslate3d = function setTranslate3d(node, translate) {
  return node.style['transform'] = translate && "translate3d(" + translate.x + "px," + translate.y + "px,0)";
};

exports.setTranslate3d = setTranslate3d;

var setTransitionDuration = function setTransitionDuration(node, duration) {
  return node.style['transitionDuration'] = duration && duration + "ms";
};

exports.setTransitionDuration = setTransitionDuration;

var isScrollable = function isScrollable(el) {
  var computedStyle = window.getComputedStyle(el);
  var overflowRegex = /(auto|scroll)/;
  var properties = ['overflow', 'overflowX', 'overflowY'];
  return properties.find(function (property) {
    return overflowRegex.test(computedStyle[property]);
  });
};

var closest = function closest(el, fn) {
  while (el) {
    if (fn(el)) {
      return el;
    }

    el = el instanceof Element && el.parentNode;
  }

  return null;
};

exports.closest = closest;

var getPosition = function getPosition(event) {
  if (event instanceof TouchEvent && event.touches && event.touches.length) {
    return {
      x: event.touches[0].pageX,
      y: event.touches[0].pageY
    };
  } else if (event instanceof TouchEvent && event.changedTouches && event.changedTouches.length) {
    return {
      x: event.changedTouches[0].pageX,
      y: event.changedTouches[0].pageY
    };
  } else if (event instanceof MouseEvent) {
    return {
      x: event.pageX,
      y: event.pageY
    };
  }

  return {
    x: 0,
    y: 0
  };
};

exports.getPosition = getPosition;

var getEdgeOffset = function getEdgeOffset(node, parent, offset) {
  if (offset === void 0) {
    offset = {
      left: 0,
      top: 0
    };
  }

  // Get the actual offsetTop / offsetLeft value, no matter how deep the node is nested
  var nodeOffset = {
    left: offset.left + node.offsetLeft,
    top: offset.top + node.offsetTop
  };

  if (node.parentNode === parent) {
    return nodeOffset;
  }

  return getEdgeOffset(node.parentNode, parent, nodeOffset);
};

exports.getEdgeOffset = getEdgeOffset;

var getScrollingParent = function getScrollingParent(el) {
  if (!(el instanceof HTMLElement)) {
    return null;
  } else if (isScrollable(el)) {
    return el;
  } else {
    return getScrollingParent(el.parentNode);
  }
};

exports.getScrollingParent = getScrollingParent;